@@ -1,4 +1,4 @@
-// Copyright (C) 2016  Stefan Vargyas
+// Copyright (C) 2016, 2017  Stefan Vargyas
 // 
 // This file is part of Json-Type.
 // 
@@ -640,7 +640,6 @@ struct json_parse_buf_t
 };
 
 #ifdef JSON_DEBUG
-
 static void json_parse_buf_print_debug(const struct json_parse_buf_t* buf)
 {
     size_t n;
@@ -654,7 +653,6 @@ static void json_parse_buf_print_debug(const struct json_parse_buf_t* buf)
     }
     print_debug_str("}");
 }
-
 #endif
 
 static inline void json_mem_buf_init(struct json_mem_buf_t* buf,
@@ -1058,8 +1056,13 @@ static bool json_parse_string_token(
             break;
 
         case JSON_STR_STATE(esc_char):
-            if (ch == 'u')
+            if (ch == 'u') {
+                if (JSON_OBJECT_CONF(disallow_unicode_esc)) {
+                    part->state = JSON_STR_STATE(error);
+                    goto loop_out;
+                }
                 part->state = JSON_STR_STATE(hexa1);
+            }
             else
             if (!IS_ASCII(ch) || (ch = unescape[ch]) == 0) {
                 part->state = JSON_STR_STATE(error);
@@ -1788,6 +1791,7 @@ bool json_config_get_param(
     switch (param) {
     case json_allow_literal_value_config:
     case json_allow_multi_objects_config:
+    case json_disallow_unicode_esc_config:
     case json_disallow_non_ascii_config:
     case json_validate_utf8_config:
         return obj->config & (SZ(1) << param);
@@ -1803,6 +1807,7 @@ void json_config_set_param(
     switch (param) {
     case json_allow_literal_value_config:
     case json_allow_multi_objects_config:
+    case json_disallow_unicode_esc_config:
     case json_disallow_non_ascii_config:
     case json_validate_utf8_config:
         if (val)
@@ -1953,7 +1958,6 @@ static const char* json_parse_error_get_desc(
 }
 
 #ifdef JSON_DEBUG
-
 const char* json_error_info_get_name(
     const struct json_error_info_t* info)
 {
@@ -1968,7 +1972,6 @@ const char* json_error_info_get_name(
         UNEXPECT_VAR("%d", info->type);
     }
 }
-
 #endif
 
 const char* json_error_info_get_desc(
